/* eslint-disable @typescript-eslint/no-unused-vars */
import { Linear } from '@antv/scale';
/**
 * Maps normalized value to normalized helix coordinate at the center of the bounding box.
 * @param params [x0, x1, y0, y1]
 * @param x x of the the bounding box of coordinate
 * @param y y of the the bounding box of coordinate
 * @param width width of the the bounding box of coordinate
 * @param height height of the the bounding box of coordinate
 * @returns transformer
 */
export var helix = function (params, x, y, width, height) {
    var _a = params, startAngle = _a[0], endAngle = _a[1], innerRadius = _a[2], outerRadius = _a[3];
    // 计算螺旋系数：r = a + b * theta
    // d = 2 * PI * b
    var count = (endAngle - startAngle) / (2 * Math.PI) + 1;
    var d = (outerRadius - innerRadius) / count;
    var b = d / (Math.PI / 2);
    // 当 theta 为 0 的时候的极径
    var step = new Linear({
        range: [innerRadius, innerRadius + d * 0.99], // 防止和下一个螺线重合
    });
    var angle = new Linear({
        range: [startAngle, endAngle],
    });
    var aspect = height / width;
    var sx = aspect > 1 ? 1 : aspect;
    var sy = aspect > 1 ? 1 / aspect : 1;
    return {
        transform: function (vector) {
            var v1 = vector[0], v2 = vector[1];
            var theta = angle.map(v1);
            var a = step.map(v2);
            // 根据长宽比调整，使得极坐标系内切外接矩形
            var x = Math.cos(theta) * (b * theta + a) * sx;
            var y = Math.sin(theta) * (b * theta + a) * sy;
            // 将坐标的原点移动到外接矩形的中心，并且将长度设置为一半
            var dx = x * 0.5 + 0.5;
            var dy = y * 0.5 + 0.5;
            return [dx, dy];
        },
        untransform: function (vector) {
            var dx = vector[0], dy = vector[1];
            var x = ((dx - 0.5) * 2) / sx;
            var y = ((dy - 0.5) * 2) / sy;
            var r = Math.sqrt(Math.pow(x, 2) + Math.pow(y, 2));
            var theta = Math.atan2(y, x);
            var a = r - b * theta;
            var v1 = angle.invert(theta);
            var v2 = step.invert(a);
            return [v1, v2];
        },
    };
};
//# sourceMappingURL=helix.js.map